package BusinessSimulation "A library for modeling & simulation of dynamical systems in the social sciences, e.g., business, economics, and ecology using the System Dynamics metaphor"
  annotation(version = "2.1.1", versionDate = "2023-05-02", revisionId = "", uses(Modelica(version = "3.2.3")), Documentation(info = "<html>
<p class=\"aside\">This information is part of the Business Simulation Library (BSL).</p>
<p>The <span style=\"color: #000080;\"><strong>BUSINESS SIMULATION LIBRARY (BSL)</strong></span> supports modeling &amp; simulation in the social sciences and ecology. Following John Sterman&nbsp;[<a href=\"modelica://BusinessSimulation.UsersGuide.References\">3</a>] the name \"Busines Simulation\" was chosen in a rather broad sense since ultimately modeling in these domains is concerned with \"control\", \"decision making\", and \"management\".</p>
<p>The <span style=\"color: #000080;\"><strong>BSL</strong> </span>follows the widespread <span style=\"color: #000080;\"><strong>System Dynamics</strong></span> metaphor and modeling approach introduced by Jay W. Forrester [<a href=\"modelica://BusinessSimulation.UsersGuide.References\">1</a>], [<a href=\"modelica://BusinessSimulation.UsersGuide.References\">2</a>].&nbsp;System Dynamics offers a very general, low-level modeling paradigm, that lends itself perfectly to model, simulate, and analyze strategic business or public policy issues.</p>
<p>Unlike existing aproaches the <span style=\"color: #000080;\"><strong>BSL</strong> </span>makes use of Modelica's acausal connectors to better distinguish&nbsp;<em>material/mass</em>&nbsp;flows from instantaneous&nbsp;<em>information</em>&nbsp;signal flows (causal connections). The approach has the additional benefit of allowing the modeler to build rather&nbsp;compact models in a fast and reliable fashion. A recent paper [<a href=\"modelica://BusinessSimulation.UsersGuide.References\">28</a>]  by the main author provides a more thorough introduction to the BSL and cyber-physical modeling in general.</p>
<p>To get started with the library, it is recommended to have a look at:</p>
<ul>
<li><strong><a href=\"modelica://BusinessSimulation.UsersGuide\">UsersGuide</a><br><br></strong></li>
<li><strong><a href=\"modelica://BusinessSimulation.Examples\">Examples<br><br></a></strong></li>
</ul>
<hr>
<h4><span style=\"color: #000080;\">Corresponding Author</span></h4>
<p>
<a href=\"modelica://BusinessSimulation.UsersGuide.Contact\">
<img src=\"modelica://BusinessSimulation/Resources/Images/UsersGuide/Contact/ContactInformation.png\" alt=\"ContactInformation.png\" width=\"400\">
</a></p>
<br>
<hr>
<h4><span style=\"color: #000080;\">Releases</span></h4>
<ul>
<li><span style=\"color: #000080;\"><a href=\"modelica://BusinessSimulation.UsersGuide.ReleaseNotes.Version_2_1_1\">Version 2.1.1 &nbsp;(2022-05-02)</a></span></li>
<li><span style=\"color: #000080;\"><a href=\"modelica://BusinessSimulation.UsersGuide.ReleaseNotes.Version_2_1_0\">Version 2.1.0 &nbsp;(2022-12-03)</a></span></li>
<li><span style=\"color: #000080;\"><a href=\"modelica://BusinessSimulation.UsersGuide.ReleaseNotes.Version_2_0_0\">Version 2.0.0 &nbsp;(2021-12-06)</a></span></li>
<li><span style=\"color: #000080;\"><a href=\"modelica://BusinessSimulation.UsersGuide.ReleaseNotes.Version_1_0_1\">Version 1.0.1 &nbsp;(2021-02-02)</a></span></li>
<li><span style=\"color: #000080;\"><a href=\"modelica://BusinessSimulation.UsersGuide.ReleaseNotes.Version_1_0_0\">Version 1.0.0 &nbsp;(2020-11-29)</a></span></li>
</ul>
<hr>
<p><span style=\"color: #000080;\"><strong>Copyright &copy; 2020 Guido Wolf Reichert</strong></span><br>Licensed unter the European Union Public Licence (EUPL), Version 1.2 or later (the \"License\")</p>
<p>You may not use this work except in compliance with the License. You may obtain a copy of the License at:<br> <a href=\"https://eur-lex.europa.eu/eli/dec_impl/2017/863/oj\">https://eur-lex.europa.eu/eli/dec_impl/2017/863/oj</a>&nbsp;(the English text for&nbsp;<a href=\"modelica://BusinessSimulation.UsersGuide.Licence\">EUPL-1.2</a>&nbsp;is included in the <a href=\"modelica://BusinessSimulation.UsersGuide\">UsersGuide</a>)</p>
<p>Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an \"AS IS\" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either expressed or implied. See the License for the specific language governing permissions and limitations under the License.</p>
<p><strong>Modelica&copy; </strong>is a registered trademark of the Modelica Association.</p>
<hr>
<br>
<p>
The freely available <strong>Lato fonts family</strong> is used by library classes; for the best visual experience it is highly recommended to install this font on your computer, which is available for download from its <a href=\"https://www.latofonts.com/lato-free-fonts/\">official site</a> or&mdash;in an earlier version&mdash;from the <a href=\"https://fonts.google.com/specimen/Lato?query=Lato\">Google Fonts</a> website.
</p>
</html>"), __Wolfram(unitConversions(conversion(derivedUnit = "wk", unit = "s", factor = 604800., offset = 0., description = "Time"), conversion(derivedUnit = "mo", unit = "s", factor = 2.628e6, offset = 0., description = "Time"), conversion(derivedUnit = "qtr", unit = "s", factor = 7.884e6, offset = 0., description = "Time"), conversion(derivedUnit = "1/wk", unit = "1/s", factor = 1.6534391534391535e-6, offset = 0., description = "Rate"), conversion(derivedUnit = "1/mo", unit = "1/s", factor = 3.8051750380517503e-7, offset = 0., description = "Rate"), conversion(derivedUnit = "1/qtr", unit = "1/s", factor = 1.2683916793505834e-7, offset = 0., description = "Rate"), conversion(derivedUnit = "bp", unit = "each", factor = 0.0001, offset = 0., description = "Amount"), conversion(derivedUnit = "percent", unit = "each", factor = 0.01, offset = 0., description = "Amount"), conversion(derivedUnit = "pair", unit = "each", factor = 2., offset = 0., description = "Amount"), conversion(derivedUnit = "doz", unit = "each", factor = 12., offset = 0., description = "Amount"), conversion(derivedUnit = "score", unit = "each", factor = 20., offset = 0., description = "Amount"), conversion(derivedUnit = "gross", unit = "each", factor = 144., offset = 0., description = "Amount"), conversion(derivedUnit = "ream", unit = "each", factor = 500, offset = 0, description = "Amount"), conversion(derivedUnit = "thousand", unit = "each", factor = 1000., offset = 0., description = "Amount"), conversion(derivedUnit = "million", unit = "each", factor = 1.e6, offset = 0., description = "Amount"), conversion(derivedUnit = "billion", unit = "each", factor = 1.e9, offset = 0., description = "Amount"), conversion(derivedUnit = "mol", unit = "each", factor = 6.02214076e23, offset = 0, description = "Amount"), conversion(derivedUnit = "each/min", unit = "each/s", factor = 0.016666666666666666, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "each/h", unit = "each/s", factor = 0.0002777777777777778, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "each/d", unit = "each/s", factor = 0.000011574074074074073, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "each/wk", unit = "each/s", factor = 1.6534391534391535e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "each/mo", unit = "each/s", factor = 3.8051750380517503e-7, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "each/qtr", unit = "each/s", factor = 1.2683916793505834e-7, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "each/yr", unit = "each/s", factor = 3.1709791983764586e-8, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/s", unit = "each/s", factor = 0.0001, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/min", unit = "each/s", factor = 1.6666666666666667e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/h", unit = "each/s", factor = 2.7777777777777777e-8, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/d", unit = "each/s", factor = 1.1574074074074074e-9, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/wk", unit = "each/s", factor = 1.6534391534391534e-10, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/mo", unit = "each/s", factor = 3.80517503805175e-11, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/qtr", unit = "each/s", factor = 1.2683916793505835e-11, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "bp/yr", unit = "each/s", factor = 3.1709791983764588e-12, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/s", unit = "each/s", factor = 0.01, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/min", unit = "each/s", factor = 0.00016666666666666666, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/h", unit = "each/s", factor = 2.777777777777778e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/d", unit = "each/s", factor = 1.1574074074074074e-7, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/wk", unit = "each/s", factor = 1.6534391534391535e-8, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/mo", unit = "each/s", factor = 3.80517503805175e-9, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/qtr", unit = "each/s", factor = 1.2683916793505834e-9, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "percent/yr", unit = "each/s", factor = 3.1709791983764586e-10, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/s", unit = "each/s", factor = 12., offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/min", unit = "each/s", factor = 0.2, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/h", unit = "each/s", factor = 0.0033333333333333335, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/d", unit = "each/s", factor = 0.0001388888888888889, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/wk", unit = "each/s", factor = 0.00001984126984126984, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/mo", unit = "each/s", factor = 4.566210045662101e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/qtr", unit = "each/s", factor = 1.5220700152207001e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "doz/yr", unit = "each/s", factor = 3.8051750380517503e-7, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/s", unit = "each/s", factor = 20., offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/min", unit = "each/s", factor = 0.3333333333333333, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/h", unit = "each/s", factor = 0.005555555555555556, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/d", unit = "each/s", factor = 0.0002314814814814815, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/wk", unit = "each/s", factor = 0.00003306878306878307, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/mo", unit = "each/s", factor = 7.6103500761035e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/qtr", unit = "each/s", factor = 2.536783358701167e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "score/yr", unit = "each/s", factor = 6.341958396752918e-7, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/s", unit = "each/s", factor = 144., offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/min", unit = "each/s", factor = 2.4, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/h", unit = "each/s", factor = 0.04, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/d", unit = "each/s", factor = 0.0016666666666666668, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/wk", unit = "each/s", factor = 0.0002380952380952381, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/mo", unit = "each/s", factor = 0.00005479452054794521, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/qtr", unit = "each/s", factor = 0.000018264840182648402, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "gross/yr", unit = "each/s", factor = 4.566210045662101e-6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/s", unit = "each/s", factor = 1000., offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/min", unit = "each/s", factor = 16.666666666666668, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/h", unit = "each/s", factor = 0.2777777777777778, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/d", unit = "each/s", factor = 0.011574074074074073, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/wk", unit = "each/s", factor = 0.0016534391534391533, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/mo", unit = "each/s", factor = 0.000380517503805175, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/qtr", unit = "each/s", factor = 0.00012683916793505834, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "thousand/yr", unit = "each/s", factor = 0.000031709791983764585, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/s", unit = "each/s", factor = 1.e6, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/min", unit = "each/s", factor = 16666.666666666668, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/h", unit = "each/s", factor = 277.77777777777777, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/d", unit = "each/s", factor = 11.574074074074074, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/wk", unit = "each/s", factor = 1.6534391534391535, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/mo", unit = "each/s", factor = 0.380517503805175, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/qtr", unit = "each/s", factor = 0.12683916793505834, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "million/yr", unit = "each/s", factor = 0.031709791983764585, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/s", unit = "each/s", factor = 1.e9, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/min", unit = "each/s", factor = 1.6666666666666666e7, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/h", unit = "each/s", factor = 277777.77777777775, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/d", unit = "each/s", factor = 11574.074074074075, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/wk", unit = "each/s", factor = 1653.4391534391534, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/mo", unit = "each/s", factor = 380.517503805175, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/qtr", unit = "each/s", factor = 126.83916793505834, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "billion/yr", unit = "each/s", factor = 31.709791983764585, offset = 0., description = "Amount Rate"), conversion(derivedUnit = "m3/h", unit = "m3/s", factor = 0.0002777777777777778, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "m3/wk", unit = "m3/s", factor = 1.6534391534391535e-6, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "m3/mo", unit = "m3/s", factor = 3.8051750380517503e-7, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "m3/qtr", unit = "m3/s", factor = 1.2683916793505834e-7, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "m3/yr", unit = "m3/s", factor = 3.1709791983764586e-8, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "cm3/s", unit = "m3/s", factor = 1.e-6, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "cm3/min", unit = "m3/s", factor = 1.6666666666666667e-8, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "cm3/h", unit = "m3/s", factor = 2.7777777777777777e-10, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "cm3/d", unit = "m3/s", factor = 1.1574074074074074e-11, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "cm3/yr", unit = "m3/s", factor = 3.1709791983764584e-14, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "dm3/s", unit = "m3/s", factor = 0.001, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "dm3/min", unit = "m3/s", factor = 0.000016666666666666667, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "dm3/h", unit = "m3/s", factor = 2.7777777777777776e-7, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "dm3/d", unit = "m3/s", factor = 1.1574074074074074e-8, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "ml/s", unit = "m3/s", factor = 1.e-6, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "ml/min", unit = "m3/s", factor = 1.6666666666666667e-8, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "ml/h", unit = "m3/s", factor = 2.7777777777777777e-10, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "ml/d", unit = "m3/s", factor = 1.1574074074074074e-11, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "l/min", unit = "m3/s", factor = 0.000016666666666666667, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "l/h", unit = "m3/s", factor = 2.7777777777777776e-7, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "l/d", unit = "m3/s", factor = 1.1574074074074074e-8, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "l/wk", unit = "m3/s", factor = 1.6534391534391535e-9, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "l/mo", unit = "m3/s", factor = 3.8051750380517503e-10, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "l/qtr", unit = "m3/s", factor = 1.2683916793505834e-10, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "l/yr", unit = "m3/s", factor = 3.1709791983764586e-11, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/s", unit = "m3/s", factor = 0.003785411784, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/min", unit = "m3/s", factor = 0.0000630901964, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/h", unit = "m3/s", factor = 1.0515032733333334e-6, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/d", unit = "m3/s", factor = 4.3812636388888886e-8, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/wk", unit = "m3/s", factor = 6.258948055555556e-9, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/mo", unit = "m3/s", factor = 1.4404154429223743e-9, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/qtr", unit = "m3/s", factor = 4.801384809741248e-10, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "gal/yr", unit = "m3/s", factor = 1.200346202435312e-10, offset = 0., description = "Volume Flow Rate"), conversion(derivedUnit = "kg/h", unit = "kg/s", factor = 0.0002777777777777778, offset = 0., description = "Mass Flow Rate"), conversion(derivedUnit = "kg/d", unit = "kg/s", factor = 0.000011574074074074073, offset = 0., description = "Mass Flow Rate"), conversion(derivedUnit = "kg/wk", unit = "kg/s", factor = 1.6534391534391535e-6, offset = 0., description = "Mass Flow Rate"), conversion(derivedUnit = "kg/mo", unit = "kg/s", factor = 3.8051750380517503e-7, offset = 0., description = "Mass Flow Rate"), conversion(derivedUnit = "kg/qtr", unit = "kg/s", factor = 1.2683916793505834e-7, offset = 0., description = "Mass Flow Rate"), conversion(derivedUnit = "kg/yr", unit = "kg/s", factor = 3.1709791983764586e-8, offset = 0., description = "Mass Flow Rate"), conversion(derivedUnit = "GW", unit = "W", factor = 1.e9, offset = 0., description = "Power"), conversion(derivedUnit = "TW", unit = "W", factor = 1.e12, offset = 0., description = "Power"), conversion(derivedUnit = "mpd", unit = "m/s", factor = 0.018626666666666666, offset = 0., description = "Velocity"), conversion(derivedUnit = "km/d", unit = "m/s", factor = 0.011574074074074073, offset = 0., description = "Velocity")), itemFlippingEnabled = true), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {76, 112, 136}, fillColor = {113, 166, 201}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-100, -100}, {100, 100}}, radius = 25), Rectangle(visible = true, origin = {0.142, -2.447}, lineColor = {255, 255, 255}, fillColor = {255, 255, 255}, lineThickness = 10, extent = {{-62.191, -62.447}, {62.191, 62.447}}), Text(visible = true, origin = {0, -30}, textColor = {255, 255, 255}, extent = {{-60, -30}, {60, 30}}, textString = "BSL", fontName = "Lato", textStyle = {TextStyle.Bold}), Polygon(visible = true, origin = {25.123, 60}, rotation = -990, lineColor = {76, 112, 136}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, points = {{-10, 10}, {10, 0}, {-10, -10}, {-10, 10}}), Polygon(visible = true, origin = {-23.947, 60}, rotation = -1170, lineColor = {255, 255, 255}, fillColor = {76, 112, 136}, fillPattern = FillPattern.Solid, points = {{-10, 10}, {10, 0}, {-10, -10}, {-10, 10}}), Rectangle(visible = true, origin = {-63.017, -0.581}, lineColor = {76, 112, 136}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 3, extent = {{-8.5, -9.419}, {8.5, 9.419}}), Rectangle(visible = true, origin = {61.5, 0}, lineColor = {255, 255, 255}, fillColor = {76, 112, 136}, fillPattern = FillPattern.Solid, lineThickness = 3, extent = {{-8.5, -9.419}, {8.5, 9.419}})}), Diagram(coordinateSystem(extent = {{-148.5, -105}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
end BusinessSimulation;
